Package 'rravif'

Title: AVIF Image Encoder
Description: Encodes images in AVIF format with 'ravif' Rust crate.
Authors: Akiru Kato [aut, cre]
Maintainer: Akiru Kato <[email protected]>
License: MIT + file LICENSE
Version: 0.1.5
Built: 2026-06-02 15:09:14 UTC
Source: https://github.com/paithiov909/rravif

Help Index


Clear the terminal screen

Description

Sends ANSI escape sequences to clear the visible screen and, when supported, the scrollback buffer of the current terminal. This is primarily intended for use in interactive sessions to reset the display before printing images or other rich output.

Note that support for clearing the scrollback buffer depends on the terminal emulator. In some environments, only the visible screen will be cleared.

This function has no effect in non-interactive sessions.

Usage

clear()

Value

Invisibly returns NULL.


Encode an AVIF image

Description

Encodes an AVIF image from a nativeRaster object.

Usage

encode(nr, quality = 80, speed = 10)

Arguments

nr

A nativeRaster object.

quality

The quality of the image.

speed

The processing speed.

Value

A raw vector containing the encoded image data.


Write an AVIF image to a file

Description

Write an AVIF image to a file

Usage

write_avif(nr, path = NULL, quality = 80, speed = 10)

Arguments

nr

A nativeRaster object.

path

The path to write the image.

quality

The quality of the image.

speed

The processing speed.

Value

If path is NULL, returns a raw vector containing the encoded image data. Otherwise, path is invisibly returned.